class APIURL:
    """
    API URL
    """
    clan = 'http://api.cr-api.com/clan/{}'
    top_clans = 'http://api.cr-api.com/top/clans'
    player = 'http://api.cr-api.com/player/{}'
    constants = 'http://api.cr-api.com/constants'
    top_players = 'http://api.cr-api.com/top/players'
