#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['crapipy']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=2.2.5',
 'async-timeout>=2.0.0',
 'asyncio>=3.4.3',
 'pytest>=3.2.3',
 'pytest-asyncio>=0.8.0',
 'python-box>=3.1.1',
 'PyYAML>=3.12',
 'requests>=2.18.4']

setup(name='crapipy',
      version='1.1',
      description='Clash Royale wrapper for cr-api.com',
      author='SML BioBot',
      author_email='smlbiobot@gmail.com',
      url='http://github.com/smlbiobot/cr-api-py',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.5',
     )
